document.addEventListener("DOMContentLoaded", function(event) {
  var container = document.getElementById("game-container");
  var player = document.getElementById("player");
  var balls = [];
  var clock = document.getElementById("clock");
  var timeLeft = 60; // Aluksi 60 sekuntia
  var startTime = performance.now();

  // Luo ja lisää kymmenen palloa peliin
  for (var i = 0; i < 10; i++) {
    var ball = document.createElement("div");
    ball.className = "ball";
    container.appendChild(ball);
    balls.push(ball);
  }

  // Aseta pelaajan alkukoordinaatit keskelle ruutua
  var playerX = container.clientWidth / 2 - player.clientWidth / 2;
  var playerY = container.clientHeight / 2 - player.clientHeight / 2;
  player.style.left = playerX + "px";
  player.style.top = playerY + "px";

  // Aseta pallojen alkukoordinaatit ja nopeudet, varmista etteivät pallot osu pelaajaan alussa
  balls.forEach(function(ball) {
    var ballX, ballY;
    var ballWidth = ball.clientWidth;
    var ballHeight = ball.clientHeight;
    var playerRect = player.getBoundingClientRect();
    var ballRect;

    do {
      ballX = Math.random() * (container.clientWidth - ballWidth);
      ballY = Math.random() * (container.clientHeight - ballHeight);
      ballRect = {
        left: ballX,
        right: ballX + ballWidth,
        top: ballY,
        bottom: ballY + ballHeight
      };
    } while (isColliding(ballRect, playerRect));

    ball.style.left = ballX + "px";
    ball.style.top = ballY + "px";
    ball.dataset.speedX = (Math.random() - 0.5) * 10; // X-suunnan nopeus (-10 - 10)
    ball.dataset.speedY = (Math.random() - 0.5) * 10; // Y-suunnan nopeus (-10 - 10)
  });

  // Liikuta pelaajaa nuolinäppäimillä
  document.addEventListener("keydown", function(event) {
    var step = 10;
    switch(event.keyCode) {
      case 37: // Vasemmalle
        playerX -= step;
        break;
      case 38: // Ylös
        playerY -= step;
        break;
      case 39: // Oikealle
        playerX += step;
        break;
      case 40: // Alas
        playerY += step;
        break;
    }
    player.style.left = playerX + "px";
    player.style.top = playerY + "px";
  });

  // Päivitä pallojen sijainti ja tarkista törmäykset
  function update() {
    balls.forEach(function(ball) {
      var ballX = parseInt(ball.style.left) || 0;
      var ballY = parseInt(ball.style.top) || 0;
      var ballWidth = ball.clientWidth;
      var ballHeight = ball.clientHeight;

      // Päivitä sijainti
      ballX += parseFloat(ball.dataset.speedX);
      ballY += parseFloat(ball.dataset.speedY);

      // Tarkista törmäykset reunoihin
      if (ballX <= 0 || ballX + ballWidth >= container.clientWidth) {
        ball.dataset.speedX *= -1;
      }
      if (ballY <= 0 || ballY + ballHeight >= container.clientHeight) {
        ball.dataset.speedY *= -1;
      }

      // Tarkista törmäys pelaajaan
      var playerRect = player.getBoundingClientRect();
      var ballRect = ball.getBoundingClientRect();
      if (isColliding(ballRect, playerRect)) {
        gameOver();
      }

      ball.style.left = ballX + "px";
      ball.style.top = ballY + "px";
    });

    requestAnimationFrame(update);
  }

  // Päivitä kelloa ja tarkista voitto/häviö
  function updateClock() {
    var currentTime = Math.floor((performance.now() - startTime) / 1000); // Kulunut aika sekunteina
    timeLeft = 60 - currentTime; // Laske jäljellä oleva aika

    if (timeLeft <= 0) {
      gameWin();
    } else {
      clock.textContent = timeLeft + " s";
      setTimeout(updateClock, 1000); // Päivitä kelloa joka sekunti
    }
  }

  // Aloita pelin päivitys
  update();
  updateClock();

  // Tarkista törmäys kahden elementin rajapintojen välillä
  function isColliding(rect1, rect2) {
    return rect1.left < rect2.right &&
           rect1.right > rect2.left &&
           rect1.top < rect2.bottom &&
           rect1.bottom > rect2.top;
  }

  // Peli päättyy, kun pelaaja osuu palloon
  function gameOver() {
    alert("Hävisit pelin!");
    location.reload(); // Uudelleenlataa sivu pelin uudelleen aloittamiseksi
  }

  // Pelaaja voittaa, kun aika loppuu
  function gameWin() {
    alert("Voitit pelin!");
    location.reload(); // Uudelleenlataa sivu pelin uudelleen aloittamiseksi
  }
});
